/**************************************************************************

   THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
   ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
   THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
   PARTICULAR PURPOSE.

   Copyright (C) 2002 by SysDesk, Holger Kuehnle.  All Rights Reserved.

   File:          rawmod.c

   Description:   This is a raw audio output module for AudioCrusher.
   		  Very simple, great as a template for
		  other output modules!

**************************************************************************/


/**************************************************************************
   Include Files
**************************************************************************/

#include <windows.h>
#include <windowsx.h>
#include <stdio.h>

#include "outmod.h"
#include "resource.h"

/**************************************************************************
   Global Variables
**************************************************************************/

FILE 		*fp;

/**************************************************************************

	DWORD rawInit(LPOMTRACKINFO omti)

	Description:   Initializes this output module (opens output file etc.).

**************************************************************************/

DWORD rawInit(LPOMTRACKINFO omti)
{
	/* Append file extension to the given filename (created by
	   AudioCrusher) AudioCrusher needs this for post-processing of the
	   created file */

	strcat(omti->szFilename,".raw");

	fp = fopen( omti->szOutFilePath, "w+b" );
	if ( !fp )
		return 0;
	else
		return -1;
}

/**************************************************************************

	DWORD rawEncode(BYTE *buf,DWORD bufLen)

	Description:   Proccesses and/or encodes the audio data in buf.

**************************************************************************/

DWORD rawEncode(BYTE *buf,DWORD bufLen)
{
	return fwrite( buf, 1, bufLen, fp );
}

/**************************************************************************

	DWORD rawClose(void)

	Description:   Finishes audio proccessing and should free all allocated
		       buffers etc., as well as close the output file.

**************************************************************************/

DWORD rawClose(void)
{
	fclose( fp );
	return -1;
}

/**************************************************************************

	LRESULT CALLBACK OptionsDlgProc( HWND hwnd, UINT uMsg, WPARAM wParam,
					 LPARAM lParam )

	Description:   Dialog procedure of the options dialog.

**************************************************************************/

LRESULT CALLBACK OptionsDlgProc( HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
	switch( uMsg ) {
		case WM_INITDIALOG:
			return TRUE;
		case WM_COMMAND:
			switch(LOWORD(wParam)) {
				case IDOK:
					/* The user has clicked Ok and is now ready to rip,
					   do something with the settings here (i.e. save config etc) */
					EndDialog(hwnd,0);
		  			return TRUE;
					break;
				case IDCANCEL:
					/* The user has clicked Cancel, discard settings */
					EndDialog(hwnd,0);
		  			return TRUE;
					break;
			}
			break;
	}
	return FALSE;
}

OUTMOD om={
           OM_VERSION,
           1,
           "RAW Audio Test Module (*.raw)",
           0,
           0,
           0,
           /* Instance handle will be set below */
           NULL,
           MAKEINTRESOURCE(IDD_OPTIONS),
           OptionsDlgProc,
           rawInit,
           rawEncode,
           rawClose
};

/**************************************************************************

	BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason,
			    LPVOID lpvReserved)

	Description:   DLL entry point function.

**************************************************************************/

BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved)
{
	/* Save the DLLs instance handle so AudioCrusher can load the options
	   dialog resource later on */
	om.hInstance=hinstDLL;

	return TRUE;
}

/**************************************************************************

	__declspec( dllexport ) OUTMOD *AudioCrusherGetOutModule(void)

	Description:   Generic output module descriptor function. Should return
		       a pointer to the output module decriptor.

**************************************************************************/

__declspec( dllexport ) OUTMOD *AudioCrusherGetOutModule(void)
{
	return &om;
}
